@@ -4,7 +4,7 @@
 @File    :   tidal.py
 @Time    :   2019/02/27
 @Author  :   Yaronzz
-@Version :   2.0
+@VERSION :   2.0
 @Contact :   yaronhuang@foxmail.com
 @Desc    :   tidal api
 '''
@@ -20,8 +20,8 @@ from aigpy.stringHelper import isNull
 from tidal_dl.model import Album, Track, Video, Artist, Playlist, StreamUrl, VideoStreamUrl
 from tidal_dl.enum import Type, AudioQuality, VideoQuality
 
-VERSION = '1.9.1'
-URL_PRE = 'https://api.tidalhifi.com/v1/'
+__VERSION__ = '1.9.1'
+__URL_PRE__ = 'https://api.tidalhifi.com/v1/'
 
 class LoginKey(object):
     def __init__(self):
@@ -56,7 +56,7 @@ class TidalAPI(object):
             header = {'authorization': 'Bearer {}'.format(self.key.accessToken)}
 
         params['countryCode'] = self.key.countryCode
-        result = requests.get(URL_PRE + path,  headers=header, params=params).json()
+        result = requests.get(__URL_PRE__ + path,  headers=header, params=params).json()
         if 'status' in result:
             if 'userMessage' in result and result['userMessage'] is not None:
                 return result['userMessage'], None
@@ -111,9 +111,9 @@ class TidalAPI(object):
             'password': password,
             'token': token,
             'clientUniqueKey': str(uuid.uuid4()).replace('-', '')[16:],
-            'clientVersion': VERSION
+            'client__VERSION__': __VERSION__
             }
-        result = requests.post(URL_PRE + 'login/username', data=data).json()
+        result = requests.post(__URL_PRE__ + 'login/username', data=data).json()
         if 'status' in result:
             if 'userMessage' in result and result['userMessage'] is not None:
                 return result['userMessage'], False
@@ -127,12 +127,16 @@ class TidalAPI(object):
         self.key.sessionId = result['sessionId']
         return None, True
     
-    def loginByAccessToken(self, accessToken):
+    def loginByAccessToken(self, accessToken, userid = None):
         header = {'authorization': 'Bearer {}'.format(accessToken)}
-        result = requests.get('https://api.tidal.com/v1/sessions', headers=header)
-        if result.status_code != 200:
+        result = requests.get('https://api.tidal.com/v1/sessions', headers=header).json()
+        if 'status' in result and result['status'] != 200:
             return "Login failed!", False
 
+        if not isNull(userid):
+            if str(result['userId']) != str(userid):
+                return "User mismatch! Please use your own accesstoken.", False
+
         self.key.userId = result['userId']
         self.key.countryCode = result['countryCode']
         self.key.accessToken = accessToken
@@ -140,7 +144,7 @@ class TidalAPI(object):
 
     def isValidSessionID(self, userId, sessionId):
         params = {'sessionId': sessionId}
-        result = requests.get(URL_PRE + 'users/' + str(userId), params=params).json()
+        result = requests.get(__URL_PRE__ + 'users/' + str(userId), params=params).json()
         if 'status' in result and not result['status'] == 200:
             return False
         return True
@@ -206,8 +210,9 @@ class TidalAPI(object):
         if msg is not None:
             return msg, None
         resp = dictToModel(data, __StreamRespon__())
-        manifest = json.loads(base64.b64decode(resp.manifest).decode('utf-8'))
+        
         if "vnd.tidal.bt" in resp.manifestMimeType:
+            manifest = json.loads(base64.b64decode(resp.manifest).decode('utf-8'))
             ret = StreamUrl()
             ret.trackid = resp.trackid
             ret.soundQuality = resp.audioQuality
@@ -223,8 +228,9 @@ class TidalAPI(object):
         if msg is not None:
             return msg, None
         resp = dictToModel(data, __StreamRespon__())
-        manifest = json.loads(base64.b64decode(resp.manifest).decode('utf-8'))
+        
         if "vnd.tidal.emu" in resp.manifestMimeType:
+            manifest = json.loads(base64.b64decode(resp.manifest).decode('utf-8'))
             array = self.__getResolutionList__(manifest['urls'][0])
             icmp = int(quality.value)
             index = 0
@@ -324,3 +330,15 @@ class TidalAPI(object):
         if obj.__class__ == Playlist:
             etype = Type.Playlist
         return msg, etype, obj
+
+    def getToken(self):
+        token1 = "MbjR4DLXz1ghC4rV"    
+        token2 = "pl4Vc0hemlAXD0mN"    # only lossless
+        try:
+            msg = requests.get( "https://cdn.jsdelivr.net/gh/yaronzz/CDN@latest/app/tidal/tokens.json", timeout=(20.05, 27.05))
+            tokens = json.loads(msg.text)
+            token1 = tokens['token']
+            token2 = tokens['token2']
+        except Exception as e:
+            pass
+        return token1,token2
